<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="et">
<context>
    <name>ColorLabel</name>
    <message>
        <location filename="../colorLabel.cpp" line="36"/>
        <source>Click to change color</source>
        <translation>Värvi muutmiseks klõpsi</translation>
    </message>
    <message>
        <location filename="../colorLabel.cpp" line="65"/>
        <source>Select Color</source>
        <translation>Vali värv</translation>
    </message>
</context>
<context>
    <name>LXQtCustomCommand</name>
    <message>
        <location filename="../lxqtcustomcommand.cpp" line="197"/>
        <source>Error</source>
        <translation>Viga</translation>
    </message>
</context>
<context>
    <name>LXQtCustomCommandConfiguration</name>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="14"/>
        <source>Custom Command Configuration</source>
        <translation>Kohandatud käskude seadistamine</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="20"/>
        <source>Display</source>
        <translation>Liides</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="211"/>
        <source>Use icon from theme or browse file</source>
        <translation>Kasuta teemale vastavat ikooni või vali oma</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="104"/>
        <source>Run with &quot;bash -c&quot;</source>
        <translation>Käivita „bash -c“ abil</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="42"/>
        <source>Select Font</source>
        <translation>Vali font</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="228"/>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="72"/>
        <source>Command</source>
        <translation>Käsk</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="35"/>
        <source>Font</source>
        <translation>Font</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="268"/>
        <source> px</source>
        <translation> pikslit</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="238"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="241"/>
        <source>Use %1 to display command output</source>
        <translation>Käsu väljundi kuvamiseks kasuta %1</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="201"/>
        <source>Icon</source>
        <translation>Ikoon</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="218"/>
        <source>Browse</source>
        <translation>Sirvi</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="28"/>
        <source>Autorotate when the panel is vertical</source>
        <translation>Kui paneel asub püstloodis, siis pööra automaatselt</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="94"/>
        <source>echo Configure...</source>
        <translation>Seadista echo...</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="97"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="308"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="325"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="342"/>
        <source>Command to run</source>
        <translation>Käivitatav käsk</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="258"/>
        <source>Max Width</source>
        <translation>Suurim laius</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="156"/>
        <source>Repeat command after:</source>
        <translation>Käsu kordamise aeg:</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="52"/>
        <source>Text Color</source>
        <translation>Teksti värv</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="62"/>
        <source>Reset</source>
        <translation>Lähtesta</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="172"/>
        <source> second(s)</source>
        <translation> sekund(it)</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="194"/>
        <source>Command outputs an image</source>
        <translation>Käsu väljundiks on pilt</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="248"/>
        <source>Tooltip</source>
        <translation>Kohtspikker</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="292"/>
        <source>Mouse Commands</source>
        <translation>Hiirekäsud</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="298"/>
        <source>Click</source>
        <translation>Klõpsimine</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="315"/>
        <source>Wheel Up</source>
        <translation>Ratta viibe üles</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="332"/>
        <source>Wheel Down</source>
        <translation>Ratta viibe alla</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="166"/>
        <source>Select Icon File</source>
        <translation>Vali ikooni fail</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="166"/>
        <source>Images (*.png *.svg *.xpm *.jpg)</source>
        <translation>Pildid (*.png *.svg *.xpm *.jpg)</translation>
    </message>
</context>
</TS>
